import React from 'react';
import Box from './Box';
import toResponsiveProps from '../modules/toResponsiveProps';
import { useTheme } from '@material-ui/core/styles';
import getFlexboxAlignForAlignProp from '../modules/getFlexboxAlignForAlignProp';
import flattenChildren from 'react-keyed-flatten-children';
import Hidden from './Hidden';
import useNegativeTopMargin from '../modules/useNegativeTopMargin';
var extractHiddenPropsFromChild = function (child) {
    return child && typeof child === 'object' && 'type' in child && child.type === Hidden
        ? child.props
        : null;
};
var useStackItemResponsiveDisplay = function (stackItem) {
    var theme = useTheme();
    var hiddenProps = extractHiddenPropsFromChild(stackItem);
    var indexOfHideBelowBreakpoint = (hiddenProps === null || hiddenProps === void 0 ? void 0 : hiddenProps.below) ? theme.breakpoints.keys.indexOf(hiddenProps === null || hiddenProps === void 0 ? void 0 : hiddenProps.below)
        : 0;
    var indexOfHideAboveBreakpoint = (hiddenProps === null || hiddenProps === void 0 ? void 0 : hiddenProps.above) ? theme.breakpoints.keys.indexOf(hiddenProps === null || hiddenProps === void 0 ? void 0 : hiddenProps.above)
        : theme.breakpoints.keys.length - 1;
    return theme.breakpoints.keys.map(function (_key, index) {
        return index <= indexOfHideAboveBreakpoint &&
            index >= indexOfHideBelowBreakpoint
            ? 'block'
            : 'none';
    });
};
var Stack = function (_a) {
    var children = _a.children, space = _a.space, align = _a.align;
    var alignItems = align && toResponsiveProps(align).map(getFlexboxAlignForAlignProp);
    var responsivePadding = toResponsiveProps(space || 0);
    var classes = useNegativeTopMargin(responsivePadding);
    return (React.createElement(Box, { className: classes.root },
        React.createElement(Box, { display: 'flex', flexDirection: 'column', alignItems: alignItems }, flattenChildren(children).map(function (stackItem, index) {
            var display = useStackItemResponsiveDisplay(stackItem);
            return (React.createElement(Box, { key: index, display: display, paddingTop: responsivePadding }, stackItem));
        }))));
};
export default Stack;
